function [bcD, bcO, bcN] = init_bcs(bc)
%function [bcD, bcO, bcN] = init_bcs(bc)
%
% This function intitialized the boundary value arrays
%
% INPUTS:
%       bc:     Array giving maximum id of each boundary type.
%                  this array is outputted from set_bcs.m
%       
% OUTPUTS:
%       bcD:    Boundary values for Dirichlet boundary conditions
%       bcO:    Boundary values for Open boundary conditions
%       bcN:    Boundary values for Neumann boundary conditions
%
% See also: set_bcs.m
%
% Written by:   Matt Ueckermann

bcD = zeros(1, bc(2));
bcO = (bc(1) + 1): bc(2);
bcN = zeros(1, bc(3) - bc(2));